// externals
import { Component, EventEmitter, Input, Output, ViewEncapsulation } from '@angular/core';
import { Router, NavigationEnd } from '@angular/router';
// internals
import { NavigationService } from './ngx-ui-navigation.service';
import template from './ngx-ui-navigation.component.html';
/**
 * @export
 * @class NavigationComponent
 * @implements {OnInit}
 */
var NavigationComponent = (function () {
    /**
     * Creates an instance of NavigationComponent.
     * @param {NavigationService} NavigationService
     * @param {Router} router
     * @memberof NavigationComponent
     */
    function NavigationComponent(navigationService, router) {
        this.navigationService = navigationService;
        this.router = router;
        this.selected = new EventEmitter();
    }
    /**
     * @memberof NavigationComponent
     */
    NavigationComponent.prototype.ngAfterViewInit = function () {
        this.navigationService.selectByUrl(this.name, this.router.url);
    };
    /**
     * @memberof NavigationComponent
     */
    NavigationComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.name) {
            this.navigation = this.navigationService.get(this.name);
            // router events
            this.router.events.subscribe(function (value) {
                if (value instanceof NavigationEnd) {
                    _this.navigationService.selectByUrl(_this.name, value.url);
                    _this.selected.emit(_this.selected);
                }
            });
        }
    };
    NavigationComponent.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: 'ngx-ui-navigation',
                    template: template
                },] },
    ];
    /** @nocollapse */
    NavigationComponent.ctorParameters = function () { return [
        { type: NavigationService, },
        { type: Router, },
    ]; };
    NavigationComponent.propDecorators = {
        'name': [{ type: Input },],
        'selected': [{ type: Output },],
    };
    return NavigationComponent;
}());
export { NavigationComponent };
//# sourceMappingURL=ngx-ui-navigation.component.js.map