import { Observable } from 'rxjs/Observable';
import { NavigationConfigInterface, NavigationInterface, NavigationItemsInterface } from './ngx-ui-navigation.interface';
/**
 * @export
 * @class NavigationConfig
 * @implements {NavigationConfigInterface}
 */
export declare class NavigationConfig implements NavigationConfigInterface {
    navigations: {
        [index: string]: NavigationInterface;
    };
}
/**
 * @export
 * @class NavigationService
 */
export declare class NavigationService {
    selected: any;
    /**
     * @private
     * @type {{
     *     [index: string]: NavigationInterface
     *   }}
     * @memberof NavigationService
     */
    private navigation;
    /**
     * Creates an instance of NavigationService.
     * @param {NavigationConfig} [config]
     * @memberof NavigationService
     */
    constructor(config?: NavigationConfig);
    /**
     * @private
     * @param {string} name
     * @param {boolean} [value]
     * @param {string} [url]
     * @returns {this}
     * @memberof NavigationService
     */
    private setSelected(name, value?, url?);
    /**
     * @private
     * @param {NavigationConfig} [config]
     * @memberof NavigationService
     */
    private init(config?);
    /**
     * @private
     * @param {string} name
     * @param {*} selected
     * @memberof NavigationService
     */
    private select(name, selected);
    /**
     * Get selected navigation item with subscribe.
     * @param {string} name
     * @returns {Observable<NavigationItemsInterface>}
     * @memberof NavigationService
     */
    selectedObservable(name: string): Observable<NavigationItemsInterface>;
    /**
     * @param {string} name
     * @returns {(NavigationInterface | undefined)}
     * @memberof NavigationServassice
     */
    get(name: string): NavigationInterface | undefined;
    /**
     * @param {string} name
     * @param {string} url
     * @memberof NavigationService
     */
    selectByUrl(name: string, url?: string): void;
}
