// external
import { Inject, Injectable, Optional } from '@angular/core';
import { Subject } from 'rxjs/Subject';
/**
 * @export
 * @class NavigationConfig
 * @implements {NavigationConfigInterface}
 */
var NavigationConfig = (function () {
    function NavigationConfig() {
    }
    NavigationConfig.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    NavigationConfig.ctorParameters = function () { return []; };
    return NavigationConfig;
}());
export { NavigationConfig };
;
/**
 * @export
 * @class NavigationService
 */
var NavigationService = (function () {
    /**
     * Creates an instance of NavigationService.
     * @param {NavigationConfig} [config]
     * @memberof NavigationService
     */
    function NavigationService(config) {
        /**
         * @private
         * @type {{
         *     [index: string]: NavigationInterface
         *   }}
         * @memberof NavigationService
         */
        this.navigation = {};
        this.init(config);
    }
    /**
     * @private
     * @param {string} name
     * @param {boolean} [value]
     * @param {string} [url]
     * @returns {this}
     * @memberof NavigationService
     */
    NavigationService.prototype.setSelected = function (name, value, url) {
        if (this.navigation[name]) {
            this.select(name, {});
            // Mark as selected when value and url
            if (this.navigation[name].hasOwnProperty('items')) {
                this.navigation[name].items.map(function (menu) {
                    menu.selected = false;
                    if (menu.items && menu.hasOwnProperty('items')) {
                        menu.items.map(function (submenu) {
                            submenu.selected = false;
                            if (submenu.routerLink === url && submenu.disabled !== true && submenu.hidden !== true) {
                                submenu.selected = value;
                                menu.selected = value;
                            }
                            return submenu;
                        });
                        return menu;
                    }
                });
                // Filter by selected true
                var menuSelected = this.navigation[name].items
                    .filter(function (menu) { return menu.selected === value; })
                    .map(function (menu, index) { return menu; })[0];
                if (menuSelected && menuSelected.items) {
                    var submenuSelected = menuSelected.items
                        .filter(function (submenu) { return submenu.selected === value; })
                        .map(function (submenu) { return submenu; })[0];
                    this.select(name, Object.assign({}, menuSelected, { selected: submenuSelected }));
                }
            }
        }
        return this;
    };
    /**
     * @private
     * @param {NavigationConfig} [config]
     * @memberof NavigationService
     */
    NavigationService.prototype.init = function (config) {
        if (config) {
            for (var type in config) {
                if (config.hasOwnProperty(type)) {
                    if (type === 'navigations') {
                        for (var nav in config[type]) {
                            if (config[type].hasOwnProperty(nav)) {
                                this.navigation[nav] = Object.assign({ selected: new Subject() }, config[type][nav]);
                            }
                        }
                    }
                }
            }
        }
    };
    /**
     * @private
     * @param {string} name
     * @param {*} selected
     * @memberof NavigationService
     */
    NavigationService.prototype.select = function (name, selected) {
        delete selected.items;
        this.selected = Object.assign({}, {
            name: this.navigation[name].name,
            selected: selected
        });
        this.navigation[name].selected.next(this.selected);
    };
    /**
     * Get selected navigation item with subscribe.
     * @param {string} name
     * @returns {Observable<NavigationItemsInterface>}
     * @memberof NavigationService
     */
    NavigationService.prototype.selectedObservable = function (name) {
        return this.navigation[name].selected.asObservable();
    };
    /**
     * @param {string} name
     * @returns {(NavigationInterface | undefined)}
     * @memberof NavigationServassice
     */
    NavigationService.prototype.get = function (name) {
        if (name) {
            return this.navigation[name];
        }
    };
    /**
     * @param {string} name
     * @param {string} url
     * @memberof NavigationService
     */
    NavigationService.prototype.selectByUrl = function (name, url) {
        this.setSelected(name, true, url);
    };
    NavigationService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    NavigationService.ctorParameters = function () { return [
        { type: NavigationConfig, decorators: [{ type: Optional }, { type: Inject, args: [NavigationConfig,] },] },
    ]; };
    return NavigationService;
}());
export { NavigationService };
//# sourceMappingURL=ngx-ui-navigation.service.js.map